@@ -19,57 +19,68 @@
 
 
 #include "kwalletpopup.h"
-
+#include <kstandardaction.h>
+#include <kactioncollection.h>
 #include <kaction.h>
 #include <kdebug.h>
-#include <kiconview.h>
+#include <k3iconview.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kwallet.h>
-#include <kstdguiitem.h>
 
 KWalletPopup::KWalletPopup(const QString& wallet, QWidget *parent, const char *name)
-: KPopupMenu(parent, name), _walletName(wallet) {
-	insertTitle(wallet);
-	KActionCollection *ac = new KActionCollection(this, "kwallet context actions");
-	KAction *act;
+: KMenu(parent), _walletName(wallet) {
+	addTitle(wallet);
+	setObjectName(name);
+	KActionCollection *ac = new KActionCollection(this/*, "kwallet context actions"*/);
+	ac->setObjectName("kwallet context actions");
+	QAction *act;
 
-	act = new KAction(i18n("&New Wallet..."), 0, 0, this,
-			SLOT(createWallet()), ac, "wallet_create");
-	act->plug(this);
+	act = ac->addAction("wallet_create");
+	act->setText(i18n("&New Wallet..."));
+	connect(act, SIGNAL(triggered(bool)), SLOT(createWallet()));
+	addAction( act );
 
-	act = new KAction(i18n("&Open..."), 0, Key_Return, this,
-			SLOT(openWallet()), ac, "wallet_open");
-	act->plug(this);
+        act= ac->addAction( "wallet-open" );
+        act->setText( i18n( "&Open..." ) );
+	connect(act, SIGNAL(triggered(bool)), SLOT(openWallet()));
+	act->setShortcut(QKeySequence(Qt::Key_Return));
+	addAction( act );
 
-	act = new KAction(i18n("Change &Password..."), 0, 0, this,
-			SLOT(changeWalletPassword()), ac, "wallet_password");
-	act->plug(this);
+        act=ac->addAction( "wallet_password" );
+        act->setText( i18n("Change &Password...") );
+	connect(act, SIGNAL(triggered(bool)), SLOT(changeWalletPassword()));
+	addAction( act );
 
-	QStringList ul = KWallet::Wallet::users(wallet);
+	const QStringList ul = KWallet::Wallet::users(wallet);
 	if (!ul.isEmpty()) {
-		KPopupMenu *pm = new KPopupMenu(this, "Disconnect Apps");
+		KMenu *pm = new KMenu(this);
+		pm->setObjectName("Disconnect Apps");
 		int id = 7000;
-		for (QStringList::Iterator it = ul.begin(); it != ul.end(); ++it) {
+		for (QStringList::const_iterator it = ul.begin(); it != ul.end(); ++it) {
 			_appMap[id] = *it;
 			pm->insertItem(*it, this, SLOT(disconnectApp(int)), 0, id);
 			pm->setItemParameter(id, id);
 			id++;
 		}
-
-		insertItem(i18n("Disconnec&t"), pm);
+                QAction *act = addMenu( pm);
+                act->setText(i18n("Disconnec&t"));
 	}
 
-	act = KStdAction::close( this,
-			SLOT(closeWallet()), ac, "wallet_close");
+	act = KStandardAction::close( this,
+			SLOT(closeWallet()), ac);
+        ac->addAction("wallet_close", act);
 	// FIXME: let's track this inside the manager so we don't need a dcop
 	//        roundtrip here.
 	act->setEnabled(KWallet::Wallet::isOpen(wallet));
-	act->plug(this);
+	addAction( act );
 
-	act = new KAction(i18n("&Delete"), 0, Key_Delete, this,
-			SLOT(deleteWallet()), ac, "wallet_delete");
-	act->plug(this);
+        act = ac->addAction( "wallet_delete" );
+        act->setText( i18n( "&Delete") );
+
+	connect(act, SIGNAL(triggered(bool)), SLOT(deleteWallet()));
+	act->setShortcut(QKeySequence(Qt::Key_Delete));
+	addAction( act );
 }
 
 
@@ -103,7 +114,7 @@ void KWalletPopup::createWallet() {
 
 
 void KWalletPopup::disconnectApp(int id) {
-	KWallet::Wallet::disconnectApplication(_walletName, _appMap[id].latin1());
+	KWallet::Wallet::disconnectApplication(_walletName, _appMap[id].toLatin1());
 }
 
 #include "kwalletpopup.moc"
