@@ -18,28 +18,30 @@
 */
 
 #include "kwmapeditor.h"
-
 #include <kaction.h>
+#include <kactioncollection.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <kpopupmenu.h>
-#include <kstdaction.h>
-#include <kwin.h>
-
-#include <qapplication.h>
-#include <qclipboard.h>
-#include <qpushbutton.h>
-#include <qtextedit.h>
+#include <kmenu.h>
+#include <kstandardaction.h>
+#include <kwindowsystem.h>
+#include <QPointer>
+#include <QApplication>
+#include <QClipboard>
+#include <QPushButton>
+#include <ktextedit.h>
+#include <QFocusEvent>
+#include <QKeyEvent>
 
 KWMapEditor::KWMapEditor(QMap<QString,QString>& map, QWidget *parent, const char *name)
-: QTable(0, 3, parent, name), _map(map) {
+: Q3Table(0, 3, parent, name), _map(map) {
 	_ac = new KActionCollection(this);
-	_copyAct = KStdAction::copy(this, SLOT(copy()), _ac);
+	_copyAct = KStandardAction::copy(this, SLOT(copy()), _ac);
 	connect(this, SIGNAL(valueChanged(int,int)), this, SIGNAL(dirty()));
 	connect(this, SIGNAL(contextMenuRequested(int,int,const QPoint&)),
 		this, SLOT(contextMenu(int,int,const QPoint&)));
-	setSelectionMode(QTable::NoSelection);
-	horizontalHeader()->setLabel(0, QString::null);
+	setSelectionMode(Q3Table::NoSelection);
+	horizontalHeader()->setLabel(0, QString());
 	horizontalHeader()->setLabel(1, i18n("Key"));
 	horizontalHeader()->setLabel(2, i18n("Value"));
 	setColumnWidth(0, 20); // FIXME: this is arbitrary
@@ -47,7 +49,7 @@ KWMapEditor::KWMapEditor(QMap<QString,QString>& map, QWidget *parent, const char
 }
 
 void KWMapEditor::reload() {
-	unsigned row = 0;
+	int row = 0;
 
 	while ((row = numRows()) > _map.count()) {
 		removeRow(row - 1);
@@ -65,7 +67,7 @@ void KWMapEditor::reload() {
 	row = 0;
 	for (QMap<QString,QString>::Iterator it = _map.begin(); it != _map.end(); ++it) {
 		setText(row, 1, it.key());
-		setText(row, 2, it.data());
+		setText(row, 2, it.value());
 		row++;
 	}
 }
@@ -117,9 +119,9 @@ void KWMapEditor::emitDirty() {
 void KWMapEditor::contextMenu(int row, int col, const QPoint& pos) {
 	_contextRow = row;
 	_contextCol = col;
-	KPopupMenu *m = new KPopupMenu(this);
-	m->insertItem(i18n("&New Entry"), this, SLOT(addEntry()));
-	_copyAct->plug(m);
+	KMenu *m = new KMenu(this);
+	m->addAction(i18n("&New Entry"), this, SLOT(addEntry()));
+	m->addAction( _copyAct );
 	m->popup(pos);
 }
 
@@ -129,25 +131,27 @@ void KWMapEditor::copy() {
 }
 
 
-class InlineEditor : public QTextEdit {
+class InlineEditor : public KTextEdit {
 	public:
-		InlineEditor(KWMapEditor *p, int row, int col) 
-		  : QTextEdit(), _p(p), row(row), col(col) { 
-			setWFlags(WStyle_NoBorder | WDestructiveClose); 
-			KWin::setType(winId(), NET::Override);
-			connect(p, SIGNAL(destroyed()), SLOT(close()));
- 		}
-		virtual ~InlineEditor() { if (!_p) return; _p->setText(row, col, text()); _p->emitDirty(); }
+	InlineEditor(KWMapEditor *p, int row, int col) : KTextEdit(), _p(p), row(row), col(col) {
+		setAttribute(Qt::WA_DeleteOnClose);
+		setWindowFlags(Qt::Widget | Qt::FramelessWindowHint);
+		connect(p, SIGNAL(destroyed()), SLOT(close()));
+	}
+	virtual ~InlineEditor() {
+		if (!_p) return;
+		_p->setText(row, col, toPlainText()); _p->emitDirty();
+	}
 
 	protected:
-		virtual void focusOutEvent(QFocusEvent*) { 
-			if (QFocusEvent::reason() == QFocusEvent::Popup) {
-				QWidget *focusW = qApp->focusWidget();
-				if (focusW && focusW == popup) {
-					return;
-				}
+		virtual void focusOutEvent(QFocusEvent *e) {
+			if (e->reason() == Qt::PopupFocusReason) {
+				// TODO: It seems we only get here if we're disturbed
+				// by our own popup. this needs some clearance though.
+				return;
 			}
-			close(); 
+
+			close();
 		}
 		virtual void keyPressEvent(QKeyEvent *e) {
 			if (e->key() == Qt::Key_Escape) {
@@ -155,31 +159,35 @@ class InlineEditor : public QTextEdit {
 				close();
 			} else {
 				e->ignore();
-				QTextEdit::keyPressEvent(e);
+				KTextEdit::keyPressEvent(e);
 			}
 		}
-		virtual QPopupMenu *createPopupMenu(const QPoint &p) {
-			popup = QTextEdit::createPopupMenu(p);
-			return popup;
+		virtual void contextMenuEvent( QContextMenuEvent *event )
+		{
+		   QMenu *menu = createStandardContextMenu();
+		   popup = menu;
+		   popup->exec( event->globalPos() );
+		   delete popup;
 		}
-		QGuardedPtr<KWMapEditor> _p;
+		QPointer<KWMapEditor> _p;
 		int row, col;
-		QGuardedPtr<QPopupMenu> popup;
+		QPointer<QMenu> popup;
 };
 
-
 QWidget *KWMapEditor::beginEdit(int row, int col, bool replace) {
-	//kdDebug(2300) << "EDIT COLUMN " << col << endl;
+	//kDebug(2300) << "EDIT COLUMN " << col ;
 	if (col != 2) {
-		return QTable::beginEdit(row, col, replace);
+		return Q3Table::beginEdit(row, col, replace);
 	}
 
 	QRect geo = cellGeometry(row, col);
-	QTextEdit *e = new InlineEditor(this, row, col);
+	KTextEdit *e = new InlineEditor(this, row, col);
+	e->setCheckSpellingEnabled(false); // disable spell-checking
 	e->setText(text(row, col));
 	e->move(mapToGlobal(geo.topLeft()));
 	e->resize(geo.width() * 2, geo.height() * 3);
 	e->show();
+	e->setFocus(Qt::PopupFocusReason);
 	return e;
 }
 
