@@ -234,6 +234,8 @@ class JobManager(QObject):
         self.jobs = {}
         self.jobiters = {}
         self.will_update_job_creation_times = False # whether timeout is set
+        self.update_job_creation_times_timer = QTimer(self)
+        self.connect(self.update_job_creation_times_timer, SIGNAL("timeout()"), self.update_job_creation_times)
         self.statusbar_set = False
         self.reasons_seen = {}
         self.connecting_to_device = {} # dict of printer->time first seen
@@ -271,9 +273,7 @@ class JobManager(QObject):
         self.release = self.rightClickMenu.addAction(i18n("_Release").replace("_",""), self.on_job_release_activate)
         self.reprint = self.rightClickMenu.addAction(i18n("Re_print").replace("_",""), self.on_job_reprint_activate)
 
-        closeAction = KStandardAction.close(self.mainWindow, SLOT("hideMainWindow()"), self.mainWindow.actionCollection());
-        self.connect(closeAction, SIGNAL("triggered(bool)"), self.hideMainWindow)
-        #FIXME PyKDE bug? KStandardAction.close(self.hideMainWindow, self.mainWindow.actionCollection())
+        closeAction = KStandardAction.close(self.hideMainWindow, self.mainWindow.actionCollection());
 
         refreshAction = self.mainWindow.actionCollection().addAction("refresh")
         refreshAction.setIcon( KIcon("view-refresh") )
@@ -298,7 +298,7 @@ class JobManager(QObject):
         try:
             bus = dbus.SystemBus()
         except:
-            print >> sys.stderr, "%s: failed to connect to system D-Bus" % PROGRAM_NAME
+            print >> sys.stderr, "%s: printer-applet failed to connect to system D-Bus"
             sys.exit (1)
 
         if AUTOCONFIGURE:
@@ -393,6 +393,7 @@ class JobManager(QObject):
                 self.mainWindow.hide()
             else:
                 self.mainWindow.show()
+                self.refresh()
 
     def on_show_completed_jobs_activate(self, activated):
         if activated:
@@ -536,26 +537,26 @@ class JobManager(QObject):
                     hours = int (ago / 3600)
                     mins = int ((ago % 3600) / 60)
                     if mins > 0:
-                        th = i18ncp("%1 in the '%1 and %2 ago' message below", "1 hour", "%1 hours", hours)
-                        tm = i18ncp("%2 in the '%1 and %2 ago' message below", "1 minute", "%1 minutes", hours)
+                        th = unicode(i18ncp("%1 in the '%1 and %2 ago' message below", "1 hour", "%1 hours", hours), 'utf-8')
+                        tm = unicode(i18ncp("%2 in the '%1 and %2 ago' message below", "1 minute", "%1 minutes", hours), 'utf-8')
                         t = i18nc("Arguments are formatted hours and minutes from the messages above", "%1 and %2 ago", th, tm)
                     else:
                         t = i18np("1 hour ago", "%1 hours ago", hours)
                 else:
                     need_update = True
-                    mins = ago / 60
+                    mins = int(ago / 60)
                     t = i18np("a minute ago", "%1 minutes ago", mins)
 
             #self.store.set_value (iter, 4, t)
             iter.setText(4, t)
 
         if need_update and not self.will_update_job_creation_times:
-            #gobject.timeout_add (60 * 1000,
-            #                     self.update_job_creation_times)
-            QTimer.singleShot(60 * 1000, self.update_job_creation_times)
+            self.update_job_creation_times_timer.setInterval(60 * 1000)
+            self.update_job_creation_times_timer.start()
             self.will_update_job_creation_times = True
 
         if not need_update:
+            self.update_job_creation_times_timer.stop()
             self.will_update_job_creation_times = False
 
         # Return code controls whether the timeout will recur.
@@ -749,9 +750,11 @@ class JobManager(QObject):
             del c
         except cups.IPPError, (e, m):
             self.show_IPP_Error (e, m)
+            self.refresh()
             return
         except RuntimeError:
             return
+        self.refresh()
 
     def on_job_hold_activate(self):
         try:
@@ -760,9 +763,11 @@ class JobManager(QObject):
             del c
         except cups.IPPError, (e, m):
             self.show_IPP_Error (e, m)
+            self.refresh()
             return
         except RuntimeError:
             return
+        self.refresh()
 
     def on_job_release_activate(self):
         try:
@@ -771,9 +776,11 @@ class JobManager(QObject):
             del c
         except cups.IPPError, (e, m):
             self.show_IPP_Error (e, m)
+            self.refresh()
             return
         except RuntimeError:
             return
+        self.refresh()
 
     def on_job_reprint_activate(self):
         try:
@@ -782,6 +789,7 @@ class JobManager(QObject):
             del c
         except cups.IPPError, (e, m):
             self.show_IPP_Error (e, m)
+            self.refresh()
             return
         except RuntimeError:
             return
@@ -915,7 +923,7 @@ if __name__ == "__main__":
     appName     = "printer-applet"
     catalogue   = "printer-applet"
     programName = ki18n("Printer Applet")
-    version     = "1.0"
+    version     = "1.2"
     description = ki18n("Applet to view current print jobs and configure new printers")
     license     = KAboutData.License_GPL
     copyright   = ki18n("2007-2008 Canonical Ltd")
