@@ -509,7 +509,7 @@ bool TaskManager::isOnTop(const Task* task)
 
     QList<WId> list = m_winModule->stackingOrder();
     QList<WId>::const_iterator begin(list.constBegin());
-    QList<WId>::const_iterator it = list.begin() + (list.size() - 1);
+    QList<WId>::const_iterator it = list.constBegin() + (list.size() - 1);
     do {
         Task::Dict::iterator taskItEnd = m_tasksByWId.end();
         for (Task::Dict::iterator taskIt = m_tasksByWId.begin();
